@@ -49,7 +49,7 @@ $lang['btn_revert']            = 'Restaurar';
 $lang['btn_register']          = 'Rexístrate';
 $lang['btn_apply']             = 'Aplicar';
 $lang['btn_media']             = 'Xestor de Arquivos-Media';
-$lang['loggedinas']            = 'Iniciaches sesión como';
+$lang['loggedinas']            = 'Iniciaches sesión como:';
 $lang['user']                  = 'Nome de Usuario';
 $lang['pass']                  = 'Contrasinal';
 $lang['newpass']               = 'Novo Contrasinal';
@@ -63,6 +63,7 @@ $lang['badlogin']              = 'Sentímolo, mais o nome de usuario ou o contra
 $lang['minoredit']             = 'Trocos Menores';
 $lang['draftdate']             = 'Borrador gardado automaticamente en';
 $lang['nosecedit']             = 'A páxina mudou entrementres, a información da sección estaba desfasada polo que se cargou a páxina completa no seu lugar.';
+$lang['searchcreatepage']      = "Se non atopaches o que estabas a procurar, podes crear ou editar a páxina co nome relacionado coa túa procura empregando o botón axeitado.";
 $lang['regmissing']            = 'Sentímolo, mais tes que cubrir todos os campos.';
 $lang['reguexists']            = 'Sentímolo, mais xa existe un usuario con ese nome.';
 $lang['regsuccess']            = 'O usuario foi creado e o contrasinal enviado por correo-e.';
@@ -88,12 +89,12 @@ $lang['license']               = 'O contido deste wiki, agás onde se indique o
 $lang['licenseok']             = 'Nota: Ao editares esta páxina estás a aceptar o licenciamento do contido baixo da seguinte licenza:';
 $lang['searchmedia']           = 'Procurar nome de arquivo:';
 $lang['searchmedia_in']        = 'Procurar en %s';
-$lang['txt_upload']            = 'Escolle o arquivo para subir';
-$lang['txt_filename']          = 'Subir como (opcional)';
+$lang['txt_upload']            = 'Escolle o arquivo para subir:';
+$lang['txt_filename']          = 'Subir como (opcional):';
 $lang['txt_overwrt']           = 'Sobrescribir arquivo existente';
 $lang['maxuploadsize']         = 'Subida máxima %s por arquivo.';
-$lang['lockedby']              = 'Bloqueado actualmente por';
-$lang['lockexpire']            = 'O bloqueo remata o';
+$lang['lockedby']              = 'Bloqueado actualmente por:';
+$lang['lockexpire']            = 'O bloqueo remata o:';
 $lang['js']['willexpire']      = 'O teu bloqueo para editares esta páxina vai caducar nun minuto.\nPara de evitar conflitos, emprega o botón de previsualización para reiniciares o contador do tempo de bloqueo.';
 $lang['js']['notsavedyet']     = 'Perderanse os trocos non gardados.
 Está certo de quereres continuar?';
@@ -175,9 +176,9 @@ $lang['diff_type']             = 'Ver diferenzas:';
 $lang['diff_inline']           = 'Por liña';
 $lang['diff_side']             = 'Cara a Cara';
 $lang['line']                  = 'Liña';
-$lang['breadcrumb']            = 'Trazado';
-$lang['youarehere']            = 'Estás aquí';
-$lang['lastmod']               = 'Última modificación';
+$lang['breadcrumb']            = 'Trazado:';
+$lang['youarehere']            = 'Estás aquí:';
+$lang['lastmod']               = 'Última modificación:';
 $lang['by']                    = 'por';
 $lang['deleted']               = 'eliminado';
 $lang['created']               = 'creado';
@@ -230,20 +231,20 @@ $lang['admin_register']        = 'Engadir novo usuario';
 $lang['metaedit']              = 'Editar Metadatos';
 $lang['metasaveerr']           = 'Non se puideron escribir os metadatos';
 $lang['metasaveok']            = 'Metadatos gardados';
-$lang['img_backto']            = 'Volver a';
-$lang['img_title']             = 'Título';
-$lang['img_caption']           = 'Lenda';
-$lang['img_date']              = 'Data';
-$lang['img_fname']             = 'Nome de arquivo';
-$lang['img_fsize']             = 'Tamaño';
-$lang['img_artist']            = 'Fotógrafo';
-$lang['img_copyr']             = 'Copyright';
-$lang['img_format']            = 'Formato';
-$lang['img_camera']            = 'Cámara';
-$lang['img_keywords']          = 'Verbas chave';
-$lang['img_width']             = 'Ancho';
-$lang['img_height']            = 'Alto';
-$lang['img_manager']           = 'Ver no xestor de arquivos-media';
+$lang['btn_img_backto']            = 'Volver a %s';
+$lang['img_title']             = 'Título:';
+$lang['img_caption']           = 'Lenda:';
+$lang['img_date']              = 'Data:';
+$lang['img_fname']             = 'Nome de arquivo:';
+$lang['img_fsize']             = 'Tamaño:';
+$lang['img_artist']            = 'Fotógrafo:';
+$lang['img_copyr']             = 'Copyright:';
+$lang['img_format']            = 'Formato:';
+$lang['img_camera']            = 'Cámara:';
+$lang['img_keywords']          = 'Verbas chave:';
+$lang['img_width']             = 'Ancho:';
+$lang['img_height']            = 'Alto:';
+$lang['btn_mediaManager']           = 'Ver no xestor de arquivos-media';
 $lang['subscr_subscribe_success'] = 'Engadido %s á lista de subscrición para %s';
 $lang['subscr_subscribe_error'] = 'Erro ao tentar engadir %s á lista de subscrición para %s';
 $lang['subscr_subscribe_noaddress'] = 'Non hai enderezos asociados co teu inicio de sesión, non é posíbel engadirte á lista de subscrición';
@@ -258,7 +259,6 @@ $lang['subscr_m_unsubscribe']  = 'Desubscribir';
 $lang['subscr_m_subscribe']    = 'Subscribir';
 $lang['subscr_m_receive']      = 'Recibir';
 $lang['subscr_style_every']    = 'correo-e en cada troco';
-$lang['authmodfailed']         = 'Configuración de autenticación de usuario incorrecta. Por favor, informa ao Administrador do teu Wiki.';
 $lang['authtempfail']          = 'A autenticación de usuario non está dispoñible de xeito temporal. De persistir esta situación, por favor, informa ao Administrador do teu Wiki.';
 $lang['authpwdexpire']         = 'A túa contrasinal expirará en %d días, deberías cambiala pronto.';
 $lang['i_chooselang']          = 'Escolle o teu idioma';
