@@ -4,14 +4,15 @@ if (!defined('DOKU_PARSER_EOL')) define('DOKU_PARSER_EOL',"\n");   // add this t
 
 class Doku_Handler {
 
-    var $Renderer = NULL;
+    var $Renderer = null;
 
-    var $CallWriter = NULL;
+    var $CallWriter = null;
 
     var $calls = array();
 
     var $status = array(
         'section' => false,
+        'doublequote' => 0,
     );
 
     var $rewriteBlocks = true;
@@ -35,8 +36,8 @@ class Doku_Handler {
         $this->CallWriter->finalise();
 
         if ( $this->status['section'] ) {
-           $last_call = end($this->calls);
-           array_push($this->calls,array('section_close',array(), $last_call[2]));
+            $last_call = end($this->calls);
+            array_push($this->calls,array('section_close',array(), $last_call[2]));
         }
 
         if ( $this->rewriteBlocks ) {
@@ -70,12 +71,12 @@ class Doku_Handler {
      */
     function plugin($match, $state, $pos, $pluginname){
         $data = array($match);
-        $plugin =& plugin_load('syntax',$pluginname);
+        $plugin = plugin_load('syntax',$pluginname);
         if($plugin != null){
             $data = $plugin->handle($match, $state, $pos, $this);
         }
         if ($data !== false) {
-          $this->addPluginCall($pluginname,$data,$state,$pos,$match);
+            $this->addPluginCall($pluginname,$data,$state,$pos,$match);
         }
         return true;
     }
@@ -190,8 +191,8 @@ class Doku_Handler {
                 // footnotes can not be nested - however due to limitations in lexer it can't be prevented
                 // we will still enter a new footnote mode, we just do nothing
                 if ($this->_footnote) {
-                  $this->_addCall('cdata',array($match), $pos);
-                  break;
+                    $this->_addCall('cdata',array($match), $pos);
+                    break;
                 }
 
                 $this->_footnote = true;
@@ -203,8 +204,8 @@ class Doku_Handler {
             case DOKU_LEXER_EXIT:
                 // check whether we have already exitted the footnote mode, can happen if the modes were nested
                 if (!$this->_footnote) {
-                  $this->_addCall('cdata',array($match), $pos);
-                  break;
+                    $this->_addCall('cdata',array($match), $pos);
+                    break;
                 }
 
                 $this->_footnote = false;
@@ -401,11 +402,17 @@ class Doku_Handler {
 
     function doublequoteopening($match, $state, $pos) {
         $this->_addCall('doublequoteopening',array(), $pos);
+        $this->status['doublequote']++;
         return true;
     }
 
     function doublequoteclosing($match, $state, $pos) {
-        $this->_addCall('doublequoteclosing',array(), $pos);
+        if ($this->status['doublequote'] <= 0) {
+            $this->doublequoteopening($match, $state, $pos);
+        } else {
+            $this->_addCall('doublequoteclosing',array(), $pos);
+            $this->status['doublequote'] = max(0, --$this->status['doublequote']);
+        }
         return true;
     }
 
@@ -423,7 +430,7 @@ class Doku_Handler {
         // Split title from URL
         $link = explode('|',$link,2);
         if ( !isset($link[1]) ) {
-            $link[1] = NULL;
+            $link[1] = null;
         } else if ( preg_match('/^\{\{[^\}]+\}\}$/',$link[1]) ) {
             // If the title is an image, convert it to an array containing the image details
             $link[1] = Doku_Handler_Parse_Media($link[1]);
@@ -433,7 +440,7 @@ class Doku_Handler {
         //decide which kind of link it is
 
         if ( preg_match('/^[a-zA-Z0-9\.]+>{1}.*$/u',$link[0]) ) {
-        // Interwiki
+            // Interwiki
             $interwiki = explode('>',$link[0],2);
             $this->_addCall(
                 'interwikilink',
@@ -441,35 +448,35 @@ class Doku_Handler {
                 $pos
                 );
         }elseif ( preg_match('/^\\\\\\\\[^\\\\]+?\\\\/u',$link[0]) ) {
-        // Windows Share
+            // Windows Share
             $this->_addCall(
                 'windowssharelink',
                 array($link[0],$link[1]),
                 $pos
                 );
         }elseif ( preg_match('#^([a-z0-9\-\.+]+?)://#i',$link[0]) ) {
-        // external link (accepts all protocols)
+            // external link (accepts all protocols)
             $this->_addCall(
                     'externallink',
                     array($link[0],$link[1]),
                     $pos
                     );
         }elseif ( preg_match('<'.PREG_PATTERN_VALID_EMAIL.'>',$link[0]) ) {
-        // E-Mail (pattern above is defined in inc/mail.php)
+            // E-Mail (pattern above is defined in inc/mail.php)
             $this->_addCall(
                 'emaillink',
                 array($link[0],$link[1]),
                 $pos
                 );
         }elseif ( preg_match('!^#.+!',$link[0]) ){
-        // local link
+            // local link
             $this->_addCall(
                 'locallink',
                 array(substr($link[0],1),$link[1]),
                 $pos
                 );
         }else{
-        // internal link
+            // internal link
             $this->_addCall(
                 'internallink',
                 array($link[0],$link[1]),
@@ -481,12 +488,12 @@ class Doku_Handler {
     }
 
     function filelink($match, $state, $pos) {
-        $this->_addCall('filelink',array($match, NULL), $pos);
+        $this->_addCall('filelink',array($match, null), $pos);
         return true;
     }
 
     function windowssharelink($match, $state, $pos) {
-        $this->_addCall('windowssharelink',array($match, NULL), $pos);
+        $this->_addCall('windowssharelink',array($match, null), $pos);
         return true;
     }
 
@@ -520,10 +527,10 @@ class Doku_Handler {
         $p['details'] = (preg_match('/\b(desc|detail)/',$params));
 
         if (preg_match('/\b(\d+)([dhm])\b/',$params,$match)) {
-          $period = array('d' => 86400, 'h' => 3600, 'm' => 60);
-          $p['refresh'] = max(600,$match[1]*$period[$match[2]]);  // n * period in seconds, minimum 10 minutes
+            $period = array('d' => 86400, 'h' => 3600, 'm' => 60);
+            $p['refresh'] = max(600,$match[1]*$period[$match[2]]);  // n * period in seconds, minimum 10 minutes
         } else {
-          $p['refresh'] = 14400;   // default to 4 hours
+            $p['refresh'] = 14400;   // default to 4 hours
         }
 
         $this->_addCall('rss',array($link,$p),$pos);
@@ -550,7 +557,7 @@ class Doku_Handler {
 
     function emaillink($match, $state, $pos) {
         $email = preg_replace(array('/^</','/>$/'),'',$match);
-        $this->_addCall('emaillink',array($email, NULL), $pos);
+        $this->_addCall('emaillink',array($email, null), $pos);
         return true;
     }
 
@@ -618,7 +625,6 @@ function Doku_Handler_Parse_Media($match) {
     // Split title from URL
     $link = explode('|',$link,2);
 
-
     // Check alignment
     $ralign = (bool)preg_match('/^ /',$link[0]);
     $lalign = (bool)preg_match('/ $/',$link[0]);
@@ -631,12 +637,12 @@ function Doku_Handler_Parse_Media($match) {
     } else if ( $lalign ) {
         $align = 'left';
     } else {
-        $align = NULL;
+        $align = null;
     }
 
     // The title...
     if ( !isset($link[1]) ) {
-        $link[1] = NULL;
+        $link[1] = null;
     }
 
     //remove aligning spaces
@@ -654,11 +660,11 @@ function Doku_Handler_Parse_Media($match) {
 
     //parse width and height
     if(preg_match('#(\d+)(x(\d+))?#i',$param,$size)){
-        ($size[1]) ? $w = $size[1] : $w = NULL;
-        ($size[3]) ? $h = $size[3] : $h = NULL;
+        !empty($size[1]) ? $w = $size[1] : $w = null;
+        !empty($size[3]) ? $h = $size[3] : $h = null;
     } else {
-        $w = NULL;
-        $h = NULL;
+        $w = null;
+        $h = null;
     }
 
     //get linking command
@@ -680,7 +686,7 @@ function Doku_Handler_Parse_Media($match) {
     }
 
     // Check whether this is a local or remote image
-    if ( preg_match('#^(https?|ftp)#i',$src) ) {
+    if ( media_isexternal($src) ) {
         $call = 'externalmedia';
     } else {
         $call = 'internalmedia';
@@ -1034,7 +1040,7 @@ class Doku_Handler_Preformatted {
                 break;
                 case 'preformatted_end':
                     if (trim($this->text)) {
-                      $this->CallWriter->writeCall(array('preformatted',array($this->text),$this->pos));
+                        $this->CallWriter->writeCall(array('preformatted',array($this->text),$this->pos));
                     }
                     // see FS#1699 & FS#1652, add 'eol' instructions to ensure proper triggering of following p_open
                     $this->CallWriter->writeCall(array('eol',array(),$this->pos));
@@ -1150,6 +1156,9 @@ class Doku_Handler_Table {
     var $currentCols = 0;
     var $firstCell = false;
     var $lastCellType = 'tablecell';
+    var $inTableHead = true;
+    var $currentRow = array('tableheader' => 0, 'tablecell' => 0);
+    var $countTableHeadRows = 0;
 
     function Doku_Handler_Table(& $CallWriter) {
         $this->CallWriter = & $CallWriter;
@@ -1217,15 +1226,24 @@ class Doku_Handler_Table {
         $this->firstCell = true;
         $this->lastCellType = 'tablecell';
         $this->maxRows++;
+        if ($this->inTableHead) {
+            $this->currentRow = array('tablecell' => 0, 'tableheader' => 0);
+        }
     }
 
     function tableRowClose($call) {
+        if ($this->inTableHead && ($this->inTableHead = $this->isTableHeadRow())) {
+            $this->countTableHeadRows++;
+        }
         // Strip off final cell opening and anything after it
         while ( $discard = array_pop($this->tableCalls ) ) {
 
             if ( $discard[0] == 'tablecell_open' || $discard[0] == 'tableheader_open') {
                 break;
             }
+            if (!empty($this->currentRow[$discard[0]])) {
+                $this->currentRow[$discard[0]]--;
+            }
         }
         $this->tableCalls[] = array('tablerow_close', array(), $call[2]);
 
@@ -1234,7 +1252,20 @@ class Doku_Handler_Table {
         }
     }
 
+    function isTableHeadRow() {
+        $td = $this->currentRow['tablecell'];
+        $th = $this->currentRow['tableheader'];
+
+        if (!$th || $td > 2) return false;
+        if (2*$td > $th) return false;
+
+        return true;
+    }
+
     function tableCell($call) {
+        if ($this->inTableHead) {
+            $this->currentRow[$call[0]]++;
+        }
         if ( !$this->firstCell ) {
 
             // Increase the span
@@ -1247,12 +1278,12 @@ class Doku_Handler_Table {
             }
 
             $this->tableCalls[] = array($this->lastCellType.'_close',array(),$call[2]);
-            $this->tableCalls[] = array($call[0].'_open',array(1,NULL,1),$call[2]);
+            $this->tableCalls[] = array($call[0].'_open',array(1,null,1),$call[2]);
             $this->lastCellType = $call[0];
 
         } else {
 
-            $this->tableCalls[] = array($call[0].'_open',array(1,NULL,1),$call[2]);
+            $this->tableCalls[] = array($call[0].'_open',array(1,null,1),$call[2]);
             $this->lastCellType = $call[0];
             $this->firstCell = false;
 
@@ -1282,6 +1313,13 @@ class Doku_Handler_Table {
         $cellKey = array();
         $toDelete = array();
 
+        // if still in tableheader, then there can be no table header
+        // as all rows can't be within <THEAD>
+        if ($this->inTableHead) {
+            $this->inTableHead = false;
+            $this->countTableHeadRows = 0;
+        }
+
         // Look for the colspan elements and increment the colspan on the
         // previous non-empty opening cell. Once done, delete all the cells
         // that contain colspans
@@ -1289,121 +1327,135 @@ class Doku_Handler_Table {
             $call = $this->tableCalls[$key];
 
             switch ($call[0]) {
-            case 'tablerow_open':
-
-                $lastRow++;
-                $lastCell = 0;
-                break;
-
-            case 'tablecell_open':
-            case 'tableheader_open':
-
-                $lastCell++;
-                $cellKey[$lastRow][$lastCell] = $key;
-                break;
-
-            case 'table_align':
-
-                $prev = in_array($this->tableCalls[$key-1][0], array('tablecell_open', 'tableheader_open'));
-                $next = in_array($this->tableCalls[$key+1][0], array('tablecell_close', 'tableheader_close'));
-                // If the cell is empty, align left
-                if ($prev && $next) {
-                    $this->tableCalls[$key-1][1][1] = 'left';
-
-                // If the previous element was a cell open, align right
-                } elseif ($prev) {
-                    $this->tableCalls[$key-1][1][1] = 'right';
-
-                // If the next element is the close of an element, align either center or left
-                } elseif ( $next) {
-                    if ( $this->tableCalls[$cellKey[$lastRow][$lastCell]][1][1] == 'right' ) {
-                        $this->tableCalls[$cellKey[$lastRow][$lastCell]][1][1] = 'center';
-                    } else {
-                        $this->tableCalls[$cellKey[$lastRow][$lastCell]][1][1] = 'left';
+                case 'table_open' :
+                    if($this->countTableHeadRows) {
+                        array_splice($this->tableCalls, $key+1, 0, array(
+                              array('tablethead_open', array(), $call[2]))
+                        );
                     }
+                    break;
 
-                }
+                case 'tablerow_open':
 
-                // Now convert the whitespace back to cdata
-                $this->tableCalls[$key][0] = 'cdata';
-                break;
+                    $lastRow++;
+                    $lastCell = 0;
+                    break;
 
-            case 'colspan':
+                case 'tablecell_open':
+                case 'tableheader_open':
 
-                $this->tableCalls[$key-1][1][0] = false;
+                    $lastCell++;
+                    $cellKey[$lastRow][$lastCell] = $key;
+                    break;
 
-                for($i = $key-2; $i >= $cellKey[$lastRow][1]; $i--) {
+                case 'table_align':
 
-                    if ( $this->tableCalls[$i][0] == 'tablecell_open' || $this->tableCalls[$i][0] == 'tableheader_open' ) {
+                    $prev = in_array($this->tableCalls[$key-1][0], array('tablecell_open', 'tableheader_open'));
+                    $next = in_array($this->tableCalls[$key+1][0], array('tablecell_close', 'tableheader_close'));
+                    // If the cell is empty, align left
+                    if ($prev && $next) {
+                        $this->tableCalls[$key-1][1][1] = 'left';
 
-                        if ( false !== $this->tableCalls[$i][1][0] ) {
-                            $this->tableCalls[$i][1][0]++;
-                            break;
+                    // If the previous element was a cell open, align right
+                    } elseif ($prev) {
+                        $this->tableCalls[$key-1][1][1] = 'right';
+
+                    // If the next element is the close of an element, align either center or left
+                    } elseif ( $next) {
+                        if ( $this->tableCalls[$cellKey[$lastRow][$lastCell]][1][1] == 'right' ) {
+                            $this->tableCalls[$cellKey[$lastRow][$lastCell]][1][1] = 'center';
+                        } else {
+                            $this->tableCalls[$cellKey[$lastRow][$lastCell]][1][1] = 'left';
                         }
 
-
                     }
-                }
 
-                $toDelete[] = $key-1;
-                $toDelete[] = $key;
-                $toDelete[] = $key+1;
-                break;
-
-            case 'rowspan':
-
-                if ( $this->tableCalls[$key-1][0] == 'cdata' ) {
-                    // ignore rowspan if previous call was cdata (text mixed with :::) we don't have to check next call as that wont match regex
+                    // Now convert the whitespace back to cdata
                     $this->tableCalls[$key][0] = 'cdata';
+                    break;
 
-                } else {
+                case 'colspan':
 
-                    $spanning_cell = null;
-                    for($i = $lastRow-1; $i > 0; $i--) {
+                    $this->tableCalls[$key-1][1][0] = false;
 
-                        if ( $this->tableCalls[$cellKey[$i][$lastCell]][0] == 'tablecell_open' || $this->tableCalls[$cellKey[$i][$lastCell]][0] == 'tableheader_open' ) {
+                    for($i = $key-2; $i >= $cellKey[$lastRow][1]; $i--) {
 
-                            if ($this->tableCalls[$cellKey[$i][$lastCell]][1][2] >= $lastRow - $i) {
-                                $spanning_cell = $i;
+                        if ( $this->tableCalls[$i][0] == 'tablecell_open' || $this->tableCalls[$i][0] == 'tableheader_open' ) {
+
+                            if ( false !== $this->tableCalls[$i][1][0] ) {
+                                $this->tableCalls[$i][1][0]++;
                                 break;
                             }
 
-
                         }
                     }
-                    if (is_null($spanning_cell)) {
-                        // No spanning cell found, so convert this cell to
-                        // an empty one to avoid broken tables
-                        $this->tableCells[$key][1][1] = '';
-                        continue;
-                    }
-                    $this->tableCalls[$cellKey[$spanning_cell][$lastCell]][1][2]++;
-
-                    $this->tableCalls[$key-1][1][2] = false;
 
                     $toDelete[] = $key-1;
                     $toDelete[] = $key;
                     $toDelete[] = $key+1;
-                }
-                break;
+                    break;
 
-            case 'tablerow_close':
+                case 'rowspan':
 
-                // Fix broken tables by adding missing cells
-                while (++$lastCell < $this->maxCols) {
-                    array_splice($this->tableCalls, $key, 0, array(
-                           array('tablecell_open', array(1, null, 1), $call[2]),
-                           array('cdata', array(''), $call[2]),
-                           array('tablecell_close', array(), $call[2])));
-                    $key += 3;
-                }
+                    if ( $this->tableCalls[$key-1][0] == 'cdata' ) {
+                        // ignore rowspan if previous call was cdata (text mixed with :::) we don't have to check next call as that wont match regex
+                        $this->tableCalls[$key][0] = 'cdata';
 
-                break;
+                    } else {
+
+                        $spanning_cell = null;
+
+                        // can't cross thead/tbody boundary
+                        if (!$this->countTableHeadRows || ($lastRow-1 != $this->countTableHeadRows)) {
+                            for($i = $lastRow-1; $i > 0; $i--) {
+
+                                if ( $this->tableCalls[$cellKey[$i][$lastCell]][0] == 'tablecell_open' || $this->tableCalls[$cellKey[$i][$lastCell]][0] == 'tableheader_open' ) {
+
+                                    if ($this->tableCalls[$cellKey[$i][$lastCell]][1][2] >= $lastRow - $i) {
+                                        $spanning_cell = $i;
+                                        break;
+                                    }
+
+                                }
+                            }
+                        }
+                        if (is_null($spanning_cell)) {
+                            // No spanning cell found, so convert this cell to
+                            // an empty one to avoid broken tables
+                            $this->tableCalls[$key][0] = 'cdata';
+                            $this->tableCalls[$key][1][0] = '';
+                            continue;
+                        }
+                        $this->tableCalls[$cellKey[$spanning_cell][$lastCell]][1][2]++;
+
+                        $this->tableCalls[$key-1][1][2] = false;
+
+                        $toDelete[] = $key-1;
+                        $toDelete[] = $key;
+                        $toDelete[] = $key+1;
+                    }
+                    break;
+
+                case 'tablerow_close':
+
+                    // Fix broken tables by adding missing cells
+                    while (++$lastCell < $this->maxCols) {
+                        array_splice($this->tableCalls, $key, 0, array(
+                               array('tablecell_open', array(1, null, 1), $call[2]),
+                               array('cdata', array(''), $call[2]),
+                               array('tablecell_close', array(), $call[2])));
+                        $key += 3;
+                    }
+
+                    if($this->countTableHeadRows == $lastRow) {
+                        array_splice($this->tableCalls, $key+1, 0, array(
+                              array('tablethead_close', array(), $call[2])));
+                    }
+                    break;
 
             }
         }
 
-
         // condense cdata
         $cnt = count($this->tableCalls);
         for( $key = 0; $key < $cnt; $key++){
@@ -1435,12 +1487,13 @@ class Doku_Handler_Table {
 class Doku_Handler_Block {
     var $calls = array();
     var $skipEol = false;
+    var $inParagraph = false;
 
     // Blocks these should not be inside paragraphs
     var $blockOpen = array(
             'header',
             'listu_open','listo_open','listitem_open','listcontent_open',
-            'table_open','tablerow_open','tablecell_open','tableheader_open',
+            'table_open','tablerow_open','tablecell_open','tableheader_open','tablethead_open',
             'quote_open',
             'code','file','hr','preformatted','rss',
             'htmlblock','phpblock',
@@ -1450,7 +1503,7 @@ class Doku_Handler_Block {
     var $blockClose = array(
             'header',
             'listu_close','listo_close','listitem_close','listcontent_close',
-            'table_close','tablerow_close','tablecell_close','tableheader_close',
+            'table_close','tablerow_close','tablecell_close','tableheader_close','tablethead_close',
             'quote_close',
             'code','file','hr','preformatted','rss',
             'htmlblock','phpblock',
